Our goals
=========

One of our primary goals is to establish a better communication network between
compatible hardware, for automatic data exchange between ships.

We want to aggregate all the information that is currently thrown away on shipbridges
all over the world and make the best free map of the ocean.

This vast ressource of currently nearly unused data will also help scientists
understand our oceans better.